==> qtjambi-qt3drender-5.15.8-sources.jar: io/qt/qt3d/render/QFrustumCulling.java <==
package io.qt.qt3d.render;


/**
 * <p>Enable frustum culling for the FrameGraph</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qfrustumculling.html">Qt3DRender::QFrustumCulling</a></p>
 */
public class QFrustumCulling extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrustumCulling.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFrustumCulling(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrustumCulling() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfrustumculling.html#QFrustumCulling">Qt3DRender::QFrustumCulling::QFrustumCulling(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QFrustumCulling(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrustumCulling instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QFrustumCulling(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QFrustumCulling(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QFrustumCulling instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QFrustumCulling.java <==
package io.qt.qt3d.render;


/**
 * <p>Enable frustum culling for the FrameGraph</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qfrustumculling.html">Qt3DRender::QFrustumCulling</a></p>
 */
public class QFrustumCulling extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrustumCulling.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFrustumCulling(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrustumCulling() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfrustumculling.html#QFrustumCulling">Qt3DRender::QFrustumCulling::QFrustumCulling(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QFrustumCulling(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrustumCulling instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QFrustumCulling(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QFrustumCulling(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QFrustumCulling instance, QDeclarativeConstructor constructor);
    
}
